#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# flake8: noqa

extensions = ["sphinx.ext.autodoc", "jaraco.packaging.sphinx", "rst.linker"]

master_doc = "index"

link_files = {
    "../CHANGES.rst": dict(
        using=dict(GH="https://github.com"),
        replace=[
            dict(
                pattern=r"(Issue #|\B#)(?P<issue>\d+)",
                url="{package_url}/issues/{issue}",
            ),
            dict(
                pattern=r"^(?m)((?P<scm_version>v?\d+(\.\d+){1,2}))\n[-=]+\n",
                with_scm="{text}\n{rev[timestamp]:%d %b %Y}\n",
            ),
            dict(
                pattern=r"PEP[- ](?P<pep_number>\d+)",
                url="https://www.python.org/dev/peps/pep-{pep_number:0>4}/",
            ),
        ],
    )
}

# Custom sidebar templates, maps document names to template names.
html_theme = 'alabaster'
templates_path = ['_templates']
html_sidebars = {'index': 'tidelift-sidebar.html'}



import platform

collect_ignore = [
    "hook-keyring.backend.py",
]

if platform.system() != 'Darwin':
    collect_ignore.append('keyring/backends/_OS_X_API.py')

collect_ignore.append('keyring/devpi_client.py')
